#!/usr/bin/ruby

class Event
  attr_accessor :start_time
  attr_accessor :type
  attr_accessor :description
  
  def initialize(time, type, description)
    @start_time = time
    @type = type
    @description = description
  end

  def to_srt
    return "%{start_time} --> %{end_time}\n%{type} : %{description}" % {
      :start_time => @start_time.strftime("00:%M:%S,000"),
      # the + # is the duration the panel will be up
      :end_time => (@start_time + 3).strftime("00:%M:%S,000"),
      :type => @type,
      :description => @description
    }    
  end
end

def makeEventsFromInputLines(lines)
  results = Array.new

  lines.each { | line |
    matched = /(?<minutes>\d+):(?<seconds>\d+) - (?<type>\w+) : (?<description>.*)/.match(line)
    if matched
      event = Event.new(Time.at((matched["minutes"].to_i * 60) + matched["seconds"].to_i),
                        matched["type"],
                        matched["description"])
      
      results.push(event)
    end
  }

  return results
end

def outputEventsAsSRT(events)
  events.each_with_index { | event, i |
    puts "%{index}\n%{srt_data}\n\n" % {
      :index => i + 1,
      :srt_data => event.to_srt
    }
  }
  
  return true
end

lines = IO.readlines(ARGV[0])
events = makeEventsFromInputLines(lines)
outputEventsAsSRT(events)
